.. heatgraphy documentation master file, created by
   sphinx-quickstart on Tue Oct 25 15:51:41 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to heatgraphy's documentation!
======================================

Installation
------------

To install heatgraphy

.. code-block:: shell

   pip install heatgraphy

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   Tutorial <tutorial/index>
   Gallery <auto_examples/index>
   API <api/index>



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
